==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/ca.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "El pas 1 ha fallat. Excepció: %s",
    "Step 2 failed. Exception: %s" : "El pas 2 ha fallat. Excepció: %s",
    "External storage" : "Emmagatzemament extern",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Grant access" : "Concedeix accés",
    "Generate keys" : "Generar claus",
    "Error generating key pair" : "Error en generar el parell de claus",
    "All users. Type to select user or group." : "Tots els usuaris. Escriu per seleccionar un usuari o grup.",
    "(group)" : "(grup)",
    "Saved" : "Desat",
    "Username" : "Nom d'usuari",
    "Password" : "Contrasenya",
    "Save" : "Desa",
    "Storage with id \"%i\" not found" : "No s'ha trobat emmagatzematge amb id \"%i\"",
    "Invalid mount point" : "Punt de muntatge no vàlid",
    "Invalid storage backend \"%s\"" : "Motor d'emmagatzematge no vàlid \"%s\"",
    "None" : "Cap",
    "App key" : "Clau de l'aplicació",
    "App secret" : "Secret de l'aplicació",
    "Client ID" : "Client ID",
    "Client secret" : "Secret del client",
    "API key" : "codi API",
    "Public key" : "Clau pública",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Cub",
    "Hostname" : "Nom del servidor",
    "Port" : "Port",
    "Region" : "Comarca",
    "Enable SSL" : "Habilita SSL",
    "Enable Path Style" : "Permet l'estil del camí",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subcarpeta remota",
    "Secure https://" : "Protocol segur https://",
    "Host" : "Equip remot",
    "Secure ftps://" : "Protocol segur ftps://",
    "Local" : "Local",
    "Location" : "Ubicació",
    "ownCloud" : "ownCloud",
    "Root" : "Arrel",
    "SFTP with secret key login" : "Inici de sessió SFTP amb clau secreta",
    "Share" : "Comparteix",
    "SMB / CIFS using OC login" : "SMB / CIFS usant acreditació OC",
    "Username as share" : "Nom d'usuari per compartir",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "<b>Note:</b> " : "<b>Nota:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> El suport cURL no està activat o instal·lat a PHP. No es pot muntar %s. Demaneu a l'administrador del sistema que l'instal·li.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> El suport FTP per PHP no està activat o no està instal·lat. No es pot muntar %s. Demaneu a l'administrador del sistema que l'instal·li.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> %s no està instal·lat. No es pot muntar %s. Demaneu a l'administrador del sistema que l'instal·li.",
    "No external storage configured" : "Sense emmagatzematge extern configurat",
    "You can add external storages in the personal settings" : "Pot agregar emmagatzematges externs en la configuració personal",
    "Name" : "Nom",
    "Storage type" : "Tipus d'emmagatzemament",
    "Scope" : "Abast",
    "Enable encryption" : "Habilitar xifrat",
    "Enable previews" : "Habilitar vistes prèvies",
    "Check for changes" : "Comproveu si hi ha canvis",
    "Never" : "Mai",
    "Once every direct access" : "Un cop cada accés directe",
    "External Storage" : "Emmagatzemament extern",
    "Folder name" : "Nom de la carpeta",
    "Configuration" : "Configuració",
    "Available for" : "Disponible per",
    "Add storage" : "Afegeix emmagatzemament",
    "Advanced settings" : "Configuració avançada",
    "Delete" : "Esborra",
    "Allow users to mount the following external storage" : "Permet als usuaris muntar els dispositius externs següents"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/ca.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Emmagatzematge extern",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Grant access" : "Concedeix accés",
    "Generate keys" : "Generar claus",
    "Error generating key pair" : "Error en generar el parell de claus",
    "All users. Type to select user or group." : "Tots els usuaris. Escriu per seleccionar un usuari o grup.",
    "(group)" : "(grup)",
    "Admin defined" : "Administrador definit",
    "Delete storage?" : "Esborro l'emmagatzematge?",
    "Saved" : "Desat",
    "Saving..." : "Desant...",
    "Save" : "Desa",
    "external-storage" : "Emmagatzematge extern",
    "Username" : "Nom d'usuari",
    "Password" : "Contrasenya",
    "Credentials saved" : "Credencials desades",
    "Invalid mount point" : "Punt de muntatge no vàlid",
    "Invalid storage backend \"%s\"" : "Motor d'emmagatzematge no vàlid \"%s\"",
    "%s" : "%s",
    "Access key" : "Clau d'accés",
    "Secret key" : "Clau secreta",
    "None" : "Cap",
    "App key" : "Clau de l'aplicació",
    "App secret" : "Secret de l'aplicació",
    "Client ID" : "Client ID",
    "Client secret" : "Secret del client",
    "Domain" : "Domini",
    "API key" : "codi API",
    "Username and password" : "Nom d'usuari i contrasenya",
    "Public key" : "Clau pública",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Cub",
    "Hostname" : "Nom del servidor",
    "Port" : "Port",
    "Region" : "Comarca",
    "Enable SSL" : "Habilita SSL",
    "Enable Path Style" : "Permet l'estil del camí",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subcarpeta remota",
    "Secure https://" : "Protocol segur https://",
    "FTP" : "FTP",
    "Host" : "Equip remot",
    "Secure ftps://" : "Protocol segur ftps://",
    "Local" : "Local",
    "Location" : "Ubicació",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Arrel",
    "SFTP with secret key login" : "Inici de sessió SFTP amb clau secreta",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Comparteix",
    "SMB / CIFS using OC login" : "SMB / CIFS usant acreditació OC",
    "Username as share" : "Nom d'usuari per compartir",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nom del servei",
    "Name" : "Nom",
    "Storage type" : "Tipus d'emmagatzematge",
    "Scope" : "Abast",
    "Enable encryption" : "Habilitar xifrat",
    "Enable previews" : "Habilitar vistes prèvies",
    "Enable sharing" : "Habilita la compartició",
    "Check for changes" : "Comproveu si hi ha canvis",
    "Never" : "Mai",
    "Once every direct access" : "Un cop cada accés directe",
    "Folder name" : "Nom de la carpeta",
    "External storage" : "Emmagatzematge extern",
    "Authentication" : "Autenticació",
    "Configuration" : "Configuració",
    "Available for" : "Disponible per",
    "Add storage" : "Afegeix emmagatzematge",
    "Advanced settings" : "Configuració avançada",
    "Delete" : "Esborra",
    "Allow users to mount the following external storage" : "Permet als usuaris muntar els dispositius externs següents",
    "No external storage configured" : "Sense emmagatzematge extern configurat",
    "You can add external storages in the personal settings" : "Pot agregar emmagatzematges externs en la configuració personal"
},
"nplurals=2; plural=(n != 1);");
